summaryrefslogtreecommitdiffstats
path: root/cpukit/itron/src/mbox.c
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/itron/src/mbox.c')
-rw-r--r--cpukit/itron/src/mbox.c21
1 files changed, 11 insertions, 10 deletions
diff --git a/cpukit/itron/src/mbox.c b/cpukit/itron/src/mbox.c
index cff86d71e7..7990a11976 100644
--- a/cpukit/itron/src/mbox.c
+++ b/cpukit/itron/src/mbox.c
@@ -36,17 +36,18 @@ void _ITRON_Mailbox_Manager_initialization(
)
{
_Objects_Initialize_information(
- &_ITRON_Mailbox_Information, /* object information table */
- OBJECTS_ITRON_MAILBOXES, /* object class */
- FALSE, /* TRUE if this is a global */
- /* object class */
- maximum_mailboxes, /* maximum objects of this class */
+ &_ITRON_Mailbox_Information, /* object information table */
+ OBJECTS_ITRON_API, /* object API */
+ OBJECTS_ITRON_MAILBOXES, /* object class */
+ maximum_mailboxes, /* maximum objects of this class */
sizeof( ITRON_Mailbox_Control ), /* size of this object's control block */
- FALSE, /* TRUE if names for this object */
- /* are strings */
- ITRON_MAXIMUM_NAME_LENGTH, /* maximum length of each object's */
- /* name */
- FALSE /* TRUE if this class is threads */
+ FALSE, /* TRUE if names for this object are strings */
+ ITRON_MAXIMUM_NAME_LENGTH /* maximum length of each object's name */
+#if defined(RTEMS_MULTIPROCESSING)
+ ,
+ FALSE, /* TRUE if this is a global object class */
+ NULL /* Proxy extraction support callout */
+#endif
);
/*